@@ -106,9 +106,9 @@ class QueuedSong(models.Model):
     index = models.IntegerField()
     manually_requested = models.BooleanField()
     votes = models.IntegerField(default=0)
-    internal_url = models.CharField(max_length=2000)
-    external_url = models.CharField(max_length=2000, blank=True)
-    stream_url = models.CharField(max_length=2000, blank=True)
+    internal_url = models.CharField(max_length=2000, blank=True, null=True)
+    external_url = models.CharField(max_length=2000)
+    stream_url = models.CharField(max_length=2000, blank=True, null=True)
     artist = models.CharField(max_length=1000)
     title = models.CharField(max_length=1000)
     duration = models.IntegerField()
@@ -131,13 +131,14 @@ class CurrentSong(models.Model):
     queue_key = models.IntegerField()
     manually_requested = models.BooleanField()
     votes = models.IntegerField()
-    internal_url = models.CharField(max_length=2000)
-    external_url = models.CharField(max_length=2000, blank=True)
-    stream_url = models.CharField(max_length=2000, blank=True)
     artist = models.CharField(max_length=1000)
     title = models.CharField(max_length=1000)
     duration = models.IntegerField()
+    internal_url = models.CharField(max_length=2000)
+    external_url = models.CharField(max_length=2000)
+    stream_url = models.CharField(max_length=2000, blank=True, null=True)
     created = models.DateTimeField(auto_now_add=True)
+    last_paused = models.DateTimeField(auto_now_add=True)
 
     def __str__(self) -> str:
         return self.title + " (" + self.internal_url + ")"
