@@ -12,13 +12,11 @@ rm -rf /usr/local/sbin/raveberry
 echo "configs"
 rm -rf /etc/hostapd/hostapd_protected.conf
 rm -rf /etc/hostapd/hostapd_unprotected.conf
-rm -rf /etc/nginx/sites-available/raveberry-events
-rm -rf /etc/nginx/sites-available/raveberry-static
-rm -rf /etc/nginx/sites-enabled/raveberry-events
-rm -rf /etc/nginx/sites-enabled/raveberry-static
+rm -rf /etc/nginx/sites-available/raveberry
+rm -rf /etc/nginx/sites-enabled/raveberry
 echo "services"
+rm -rf /etc/systemd/system/celery.service
 rm -rf /etc/systemd/system/daphne.service
-rm -rf /etc/systemd/system/gunicorn.service
 rm -rf /etc/systemd/system/homewifi.service
 rm -rf /etc/systemd/system/pulseaudio.service
 rm -rf /etc/systemd/system/remote.service
